# Fridrich-Connection

Contains:
- Communication
  - ClientConnection
  - ClientHandler
  - ServerConnection
- Encryption
  - EncryptionService
  - PrivatePublicCryption
  - FernetCryption
- Protocol
  - ProtocolInterface
  - DataProtocol
  - ControlProtocol
  - CommunicationProtocol
  - SubscriptionProtocol
